diff Core/PalanthirException.cpp @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents 491a97842e31
children
line wrap: on
line diff
--- a/Core/PalanthirException.cpp	Wed Sep 05 15:38:08 2012 +0200
+++ b/Core/PalanthirException.cpp	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -18,11 +18,11 @@
  **/
 
 
-#include "PalantirException.h"
+#include "PalanthirException.h"
 
-namespace Palantir
+namespace Palanthir
 {
-  const char* PalantirException::What() const
+  const char* PalanthirException::What() const
   {
     if (error_ == ErrorCode_Custom)
     {
@@ -35,7 +35,7 @@
   }
 
 
-  const char* PalantirException::GetDescription(ErrorCode error)
+  const char* PalanthirException::GetDescription(ErrorCode error)
   {
     switch (error)
     {
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium